# Thor's Hammer - Python Edition
(The name sounds way cooler in my head I swear) <br/>
A simple command line password generator. And yes, there WILL be more of this from other languages.

## Functionalities
Generate passwords with configurable settings for the generator, these include:
1. Configure the password's length
2. Toggle whether or not you want to generate passwords with uppercase letters.
3. Toggle whether or not you want to generate passwords with numbers.
4. Toggle whether or not you want to generate passwords with special characters.

## Installation
<ol type="1">
  <li>
    Install Python 3.x from <a href="https://www.python.org/downloads/">here</a>. (Ignore if you already have Python 3.x installed)
  </li>
  <li>
    Open terminal, run:
    
```
pip install thors_hammer
```
  </li>
</ol>

## Usage
<ol type="1">
  <li>
    Open terminal, run:

```
mjolnir
```
  </li>
  <li>
    Alternatively, in a Python file (*.py), you can do:
    
```
from thors_hammer import main
main()
```
  </li>
</ol>

## Requirement(s)
1.  Python 3.x

## Note(s)
1. Deleting the config folder/file could cause everything to revert back to the default setting the next time you boot up the progam.

## License
This project is licensed under the GNU General Public License 3.0, check [LICENSE](LICENSE) for more details.